#!/usr/bin/env python
# coding: utf-8

"""
Extract emissions and emission factors for Berlin and Jaenschwalde
"""

import os

from datetime import datetime, timedelta
from netCDF4 import Dataset

import numpy as np

import smartcarb as sc


PATH = '/project/d73/input/emissions'

# area of COSMO grid cell
AREA = 1235941.1 # in m2


def main(start, end, out_filename):

    file_exists = os.path.exists(out_filename)
    mode = 'a' if file_exists else 'w'

    with open(out_filename, mode) as outfile:

        if not file_exists:
            outfile.write('UTC time\tconstant emissions\tvariable emissions\temission factor\n')

        for time in sc.misc.iter_times(start, end, timedelta(hours=1)):
            print(time)

            filename = os.path.join(PATH, time.strftime('CO2_CO_NOX_Berlin-big_%Y%m%d%H.nc'))

            with Dataset(filename) as nc:
                variable = np.sum(nc.variables['CO2_BV_E'][:]) * AREA # kg s-1
                constant = np.sum(nc.variables['CO2_BC_E'][:]) * AREA # kg s-1

            x = variable / constant

            line = '\t'.join([str(time), '%e' % constant, '%e' % variable, '%e' % x])
            outfile.write(line)
            outfile.write('\n')





if __name__ == '__main__':
    start = datetime(2015,7,1)
    end = datetime(2016,1,1)

    main(start, end, '/users/gkuhl/projects/smartcarb/ts/ts_berlin_emissions.dat')

